# Beamr

Beamr is a markup language (and interpreter thereof) for creating PDF slide shows from simple, easy to understand text files. It uses the full power of LaTeX and its Beamer document class.

This project is still under develompent. Please visit the [installation and usage guide page](https://teonistor.github.io/beamr/).
